@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Carp qw();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Package::Autoloader::Package;
 my $PACKAGES = {};
@@ -54,9 +54,13 @@ sub import {
 	return;
 }
 
+sub assemble {
+	return($_[0]->($obtain->((caller)[0], undef)));
+}
+
 #sub debug_dump {
 #	use Data::Dumper;
 #	print STDERR Dumper($PACKAGES);
 #}
 
-1;
\ No newline at end of file
+1;
